@@ -1,27 +1,30 @@
+from __future__ import annotations
+
 import codecs
 import os
 import shlex
+from typing import Final
 
-ENCODING = os.getenv("MOCKET_ENCODING", "utf-8")
+ENCODING: Final[str] = os.getenv("MOCKET_ENCODING", "utf-8")
 
 text_type = str
 byte_type = bytes
 basestring = (str,)
 
 
-def encode_to_bytes(s, encoding=ENCODING):
+def encode_to_bytes(s: str | bytes, encoding: str = ENCODING) -> bytes:
     if isinstance(s, text_type):
         s = s.encode(encoding)
     return byte_type(s)
 
 
-def decode_from_bytes(s, encoding=ENCODING):
+def decode_from_bytes(s: str | bytes, encoding: str = ENCODING) -> str:
     if isinstance(s, byte_type):
         s = codecs.decode(s, encoding, "ignore")
     return text_type(s)
 
 
-def shsplit(s):
+def shsplit(s: str | bytes) -> list[str]:
     s = decode_from_bytes(s)
     return shlex.split(s)
 
